<?php
namespace SM\Controller;

use SM\Controller\SMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use SM\Service\Sm00001001DocumentoPropostaService;
use SM\Traits\TResponse;

class Sm00001001DocumentoPropostaController extends SMCrud
{
    use TResponse;

    public function __construct($crudService, $environment, Sm00001001DocumentoPropostaService $documentoPropostaService)
    {
        parent::__construct($crudService, $environment);
        $this->documentoPropostaService=$documentoPropostaService;
    }

    public function getDocumentoProposta()
    {   
        try {
            $data = $this->documentoPropostaService->getDocumentoProposta();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getProposta()
    {
        try {
            $data = $this->documentoPropostaService->getProposta();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTabAnexoDocumentoProposta(Request $request)
    {
        try {
            $data = $this->documentoPropostaService->getTabAnexoDocumentoProposta($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getPropostasDocumento(Request $request)
    {
        try {
            $data = $this->documentoPropostaService->getPropostasDocumento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirDocumentoProposta(DTO\Request $request)
    {
        try {
            $this->documentoPropostaService->inserirDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function editarDocumentoProposta(DTO\Request $request)
    {
        try {
            $this->documentoPropostaService->editarDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function getEscopoFaturamento(Request $request)
    {
        try {
            $data = $this->documentoPropostaService->getEscopoFaturamento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteDocumentoProposta(DTO\Request $request)
    {
        try {
            $this->documentoPropostaService->deleteDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirAnexoDocumentoProposta(Request $request)
    {
        try {
            $this->documentoPropostaService->inserirAnexoDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downloadAnexoModeloDocumentoProposta(Request $request)
    {
        $params = $request->getParameters();
        $nrorcamentodocidioma = $params["nrorcamentodocidioma"];
        $this->documentoPropostaService->downloadAnexoModeloDocumentoProposta($nrorcamentodocidioma);
    }

    public function deletarAnexoDocumentoProposta(DTO\Request $request)
    {
        try {
            $this->documentoPropostaService->deletarAnexoDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function limparAnexoModeloDocumentoProposta(DTO\Request $request)
    {
        try {
            $this->documentoPropostaService->limparAnexoModeloDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function atualizarAnexoModeloDocumentoProposta(DTO\Request $request)
    {
        try {
            $this->documentoPropostaService->atualizarAnexoModeloDocumentoProposta($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
