<?php

namespace SM\Service;

use SM\Factory\FindFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;

class FindService
{

    protected $FindFactory;
    protected $Environment;
    protected $newCode;

    public function __construct(FindFactory $FindFactory, Environment $Environment, NewCode $newCode)
    {
        $this->FindFactory  = $FindFactory;
        $this->Environment               = $Environment;
        $this->newCode                   = $newCode;
    }

    public function findContrato($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findContrato($where);
    }

    public function findHabilidades($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findHabilidades($where);
    }

    public function findEscopoFaturamento($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findEscopoFaturamento($where);
    }

    public function findModeloContrato($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findModeloContrato($where);
    }

    public function findParceiroNegocio($filtro)
    {
        $where = $this->montarFiltro($filtro);
        $operador = $this->Environment->getCdOperador();
        $params = [
            "P_CDOPERADOR" => $operador
        ];
        return $this->FindFactory->findParceiroNegocio($where, $params);
    }

    public function findOperadorHierarquia($filtro)
    {
        $where = $this->montarFiltro($filtro);
        $operador = $this->Environment->getCdOperador();
        $params = [
            "CDOPERADOR" => $operador
        ];
        return $this->FindFactory->findOperadorHierarquia($where, $params);
    }
    
    public function findIdioma($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findIdioma($where);
    }

    public function findMoeda($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findMoeda($where);
    }

    public function findProposta($filtro)
    {
        $operador = $this->Environment->getCdOperador();
        $params = [
            "CDOPERADOR" => $operador
        ];
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findProposta($where, $params);
    }

    public function findModeloProposta($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findModeloProposta($where);
    }

    public function findCentroCusto($filtro)
    {
        $where = $this->montarFiltro($filtro);
        $filial = $this->Environment->getCdFilial();
        $params = [
            "CDFILIAL" => $filial
        ];
        return $this->FindFactory->findCentroCusto($where, $params);
    }

    public function findServico($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findServico($where);
    }

    public function findOperador($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findOperador($where);
    }

    public function findPerfilAcesso($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findPerfilAcesso($where);
    }

    public function findTipoMedida($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findTipoMedida($where);
    }

    public function findModeloDocumento($filtro)
    {
        $where = $this->montarFiltro($filtro);
        return $this->FindFactory->findModeloDocumento($where);
    }

    public function montarFiltro($find)
    {
        $operador = $this->Environment->getCdOperador();
        if (empty($find)) {
            return '1 = 1';
        }
        $whereClause = [];
        foreach ($find as $column => $condition) {
            $operator = key($condition);
            $value = $condition[$operator];

            if ($value === 'OPERADOR_LOGADO') {
                $value = $operador;
            }

            if (in_array($operator, ["IN", "NOT_IN"])) {
                $value = "($value)";
            } else {
                $value = "'$value'";
            }

            $whereClause[] = "$column $operator $value";
        }

        return implode(" AND ", $whereClause);
    }
}
